FieldMut

Type Alias FieldMut 

pub type FieldMut<'a, T> = (&'static str, &'a mut T);
Named mutable reference to a struct field

The first entry of the tuple represents the name of the field and the second holds a mutable reference to the field.

Returned by NameIndex::fields_mut.