pub type Field<'a, T> = (&'static str, &'a T);Expand description
Named reference to a struct field
The first entry of the tuple represents the name of the field and the second holds a reference to the field.
Returned by NameIndex::fields.
pub type Field<'a, T> = (&'static str, &'a T);Named reference to a struct field
The first entry of the tuple represents the name of the field and the second holds a reference to the field.
Returned by NameIndex::fields.